# Guides: learn what you can do with `kernpy`

This section contains a series of guides that will help you get started with `kernpy` and learn how to use it to perform different tasks.

- [Get started](get-started.md)
